==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/autoscalingplans/kotlin/inputs/ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscalingplans.kotlin.inputs

import com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property dimensions Dimensions of the metric.
 * @property metricName Name of the metric.
 * @property namespace Namespace of the metric.
 * @property statistic Statistic of the metric. Currently, the value must always be `Sum`.
 * @property unit Unit of the metric.
 */
public data class ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs(
    public val dimensions: Output<Map<String, String>>? = null,
    public val metricName: Output<String>,
    public val namespace: Output<String>,
    public val statistic: Output<String>,
    public val unit: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs> {
    override fun toJava():
        com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs =
        com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.builder()
            .dimensions(
                dimensions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .namespace(namespace.applyValue({ args0 -> args0 }))
            .statistic(statistic.applyValue({ args0 -> args0 }))
            .unit(unit?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs].
 */
@PulumiTagMarker
public class ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgsBuilder internal
constructor() {
    private var dimensions: Output<Map<String, String>>? = null

    private var metricName: Output<String>? = null

    private var namespace: Output<String>? = null

    private var statistic: Output<String>? = null

    private var unit: Output<String>? = null

    /**
     * @param value Dimensions of the metric.
     */
    @JvmName("aqlcnfhpeemlptfk")
    public suspend fun dimensions(`value`: Output<Map<String, String>>) {
        this.dimensions = value
    }

    /**
     * @param value Name of the metric.
     */
    @JvmName("lnnvebjhxqfjqhhw")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value Namespace of the metric.
     */
    @JvmName("gwkoiaoakwovampn")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Statistic of the metric. Currently, the value must always be `Sum`.
     */
    @JvmName("uqywsexgpeyvjtiw")
    public suspend fun statistic(`value`: Output<String>) {
        this.statistic = value
    }

    /**
     * @param value Unit of the metric.
     */
    @JvmName("rbtsvurrotrwtvss")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value Dimensions of the metric.
     */
    @JvmName("vronqwwdqtivxrep")
    public suspend fun dimensions(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param values Dimensions of the metric.
     */
    @JvmName("gdtrrbelqibsegup")
    public fun dimensions(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param value Name of the metric.
     */
    @JvmName("svpyppojddnhqhlc")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value Namespace of the metric.
     */
    @JvmName("ckaqrcluactoedoh")
    public suspend fun namespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Statistic of the metric. Currently, the value must always be `Sum`.
     */
    @JvmName("rvrmpkiireeyrleg")
    public suspend fun statistic(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statistic = mapped
    }

    /**
     * @param value Unit of the metric.
     */
    @JvmName("ovvytqxbgdmgrtwm")
    public suspend fun unit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    internal fun build(): ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs =
        ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs(
            dimensions = dimensions,
            metricName = metricName ?: throw PulumiNullFieldException("metricName"),
            namespace = namespace ?: throw PulumiNullFieldException("namespace"),
            statistic = statistic ?: throw PulumiNullFieldException("statistic"),
            unit = unit,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/autoscalingplans/kotlin/inputs/ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.autoscalingplans.kotlin.inputs

import com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property dimensions Dimensions of the metric.
 * @property metricName Name of the metric.
 * @property namespace Namespace of the metric.
 * @property statistic Statistic of the metric. Currently, the value must always be `Sum`.
 * @property unit Unit of the metric.
 */
public data class ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs(
    public val dimensions: Output<Map<String, String>>? = null,
    public val metricName: Output<String>,
    public val namespace: Output<String>,
    public val statistic: Output<String>,
    public val unit: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs> {
    override fun toJava(): com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs =
        com.pulumi.aws.autoscalingplans.inputs.ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs.builder()
            .dimensions(
                dimensions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .metricName(metricName.applyValue({ args0 -> args0 }))
            .namespace(namespace.applyValue({ args0 -> args0 }))
            .statistic(statistic.applyValue({ args0 -> args0 }))
            .unit(unit?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs].
 */
@PulumiTagMarker
public class ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgsBuilder internal constructor() {
    private var dimensions: Output<Map<String, String>>? = null

    private var metricName: Output<String>? = null

    private var namespace: Output<String>? = null

    private var statistic: Output<String>? = null

    private var unit: Output<String>? = null

    /**
     * @param value Dimensions of the metric.
     */
    @JvmName("hwultdhhkyjbbeje")
    public suspend fun dimensions(`value`: Output<Map<String, String>>) {
        this.dimensions = value
    }

    /**
     * @param value Name of the metric.
     */
    @JvmName("ylpjkldujdkedjft")
    public suspend fun metricName(`value`: Output<String>) {
        this.metricName = value
    }

    /**
     * @param value Namespace of the metric.
     */
    @JvmName("rluloiospntcxbke")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Statistic of the metric. Currently, the value must always be `Sum`.
     */
    @JvmName("truxxmjwuewcdypw")
    public suspend fun statistic(`value`: Output<String>) {
        this.statistic = value
    }

    /**
     * @param value Unit of the metric.
     */
    @JvmName("gtpxxdabvxdypmms")
    public suspend fun unit(`value`: Output<String>) {
        this.unit = value
    }

    /**
     * @param value Dimensions of the metric.
     */
    @JvmName("fjdbixrceybdbrfr")
    public suspend fun dimensions(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param values Dimensions of the metric.
     */
    @JvmName("yqkqqtjylpqeadmu")
    public fun dimensions(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param value Name of the metric.
     */
    @JvmName("rfxgboioealjwgdj")
    public suspend fun metricName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricName = mapped
    }

    /**
     * @param value Namespace of the metric.
     */
    @JvmName("ofattxqxpdtnpvby")
    public suspend fun namespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Statistic of the metric. Currently, the value must always be `Sum`.
     */
    @JvmName("bubarsavqsixwbbp")
    public suspend fun statistic(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statistic = mapped
    }

    /**
     * @param value Unit of the metric.
     */
    @JvmName("bbktufmwnxlrbexq")
    public suspend fun unit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.unit = mapped
    }

    internal fun build(): ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs =
        ScalingPlanScalingInstructionCustomizedLoadMetricSpecificationArgs(
            dimensions = dimensions,
            metricName = metricName ?: throw PulumiNullFieldException("metricName"),
            namespace = namespace ?: throw PulumiNullFieldException("namespace"),
            statistic = statistic ?: throw PulumiNullFieldException("statistic"),
            unit = unit,
        )
}
